sqlobject.tests.test_mysql module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_mysql module

class `sqlobject.tests.test_mysql.` `SOTestANY`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_an_y
  `q` = so_test_an_y
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_mysql.SOTestANY`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_an_y'
  property `value`

class `sqlobject.tests.test_mysql.` `SOTestSOListMySQL`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_so_list_my_sq_l
  `q` = so_test_so_list_my_sq_l
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_mysql.SOTestSOListMySQL`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_so_list_my_sq_l'

`sqlobject.tests.test_mysql.` `test_ANY`()

`sqlobject.tests.test_mysql.` `test_list_databases`()

`sqlobject.tests.test_mysql.` `test_list_tables`()